Function enqueue
fn enqueue(outbound: &mut PacketWriter<GrowBuffer>, packet: &Packet<'_>)Expand description
Encodes a packet into the pending outbound buffer for the writer task.
fn enqueue(outbound: &mut PacketWriter<GrowBuffer>, packet: &Packet<'_>)Encodes a packet into the pending outbound buffer for the writer task.