Function flush_journal
async fn flush_journal(
client: &mut Client<JournaledSession>,
writer: &mut Option<Writer>,
)Expand description
Drain pending journal bytes and write them to the journal (if any).
async fn flush_journal(
client: &mut Client<JournaledSession>,
writer: &mut Option<Writer>,
)Drain pending journal bytes and write them to the journal (if any).