persist_and_ack

Function persist_and_ack 

async fn persist_and_ack(
    store: &mut Persistence,
    client: &mut Client<JournaledSession>,
    queued_waiting: &mut Vec<Sender<Result<(), Error>>>,
) -> Result<(), DisconnectReason>
Persists pending session ops and, on success, resolves the queued() futures the write covers. On failure both are retained for the retry after the backoff-driven reconnect.